package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.42.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.42.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````[!4``#0````(T0```````#0`(``,
M`"@`&0`8``8````T````-````#0```"``0``@`$```0````$`````P`````"
M`````@````(``!<````7````!`````$````!````````````````````L`\`
M`+`/```$`````!````$`````$````!`````0``"Q4P``L5,```4`````$```
M`0````!P````<````'```+Q.``"\3@``!``````0```!````Y,T``.3-``#D
MS0``,`(``%P"```&`````!````(```#LS0``[,T``.S-``#P````\`````8`
M```$````!````+0!``"T`0``M`$``$P```!,````!`````0```!3Y71DV`$`
M`-@!``#8`0``*````"@````$````!````%#E=&0@L0``(+$``""Q```4`0``
M%`$```0````$````4>5T9```````````````````````````!@```!````!2
MY71DY,T``.3-``#DS0``'`(``!P"```$`````0````0````4`````P```$=.
M50"&[]_N2\K30O&6>@5;V&P:N5&`000````8````!0```$=.50`!``'`!```
M``D````"``'`!`````$````O;&EB+VQD+6UU<VPM:3,X-BYS;RXQ```1````
M1P````@````(`````!`0`"5`!(`H`!`$H(8`A("!``(+(`0).(`208H$"`@`
M````1P```$L```!/````4````%<```!8````60````````!;````7```````
M``!=````7@```&```````````````&I_FGSJT^\.SMY'+6_%WQ\NQ9NVN(WQ
M#M1DU'PA_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!F$_#F[OCDGQ5PSS2
M9Z_,9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FL:GE"CX/M)````````````
M``````````$``````````````!(````)```````````````1````R`$`````
M````````$0```%$!`````````````!(````0```````````````2````H0$`
M````````````$@```!@``````````````!(```#=`@`````````````2````
MU0$`````````````$@```*T!`````````````!(```#H`@`````````````A
M````'P``````````````$@```"4``````````````!(````L````````````
M```2````G@(`````````````$@```+0"`````````````!(```#P`0``````
M```````2````,P``````````````$@```'8"`````````````!(````Z````
M```````````2````0@``````````````$@```)<"`````````````!(```!*
M```````````````2````7P(`````````````$@```%(``````````````!(`
M``!;```````````````@````K0(`````````````$@```'<`````````````
M`!(```!\```````````````2````;@$`````````````%@```'T"````````
M`````!(````=`@`````````````2````A0``````````````$@```(P`````
M`````````"`````/`@`````````````2````.P,`````````````$@```(@"
M`````````````!$```#G`@`````````````1````00(`````````````$@``
M`,L"`````````````!(```#I`@`````````````1````J@``````````````
M$@```%\!`````````````!(```"S```````````````B````P@``````````
M````$@```'T``````````````!(````M`@`````````````2````QP``````
M````````(````&H"`````````````!(```#A```````````````2````D@$`
M````````````$@```.8``````````````"`````"`0`````````````2````
M3P(`````````````$@````@!`````````````!(```"!`0`````````````2
M````%@$`````````````$@```"<!`````````````!(```#K`0``````````
M```2````_`$`````````````$@```"T!`````````````!(````V`@``````
M```````2````I@(`````````````$@```,,"`````````````!(````\`0``
M```````````2````Y@$`````````````$@```$,!`````````````!(```#Q
M`@`````````````2````Y@(`````````````(0```$H!`````````````!(`
M``#8`@``L!,``#P"```2``P`P@$``*IC```!````$@`-`'T#``"0*0``$`<`
M`!(`#``Q!```T#(``,4````2``P`6@,``*`>```%````$@`,`.\#````$```
M`0```!(`"0"@`P``H#```"\"```2``P`%00``+`>``!(`@``$@`,`-@#```4
MT````````!``%@!K`P``T"@``+P````2``P`B@,``$`=```V````$@`,`)(#
M``!@)@``80```!(`#`"V`P``L%X``&X"```2``P`RP,````A```R````$@`,
M`.0#``#0)@``-````!(`#``L!```0-`````````0`!8`(`,```<6```W````
M$@`,`/4#``!`(0``Z0```!(`#`#!`P``$-````0````1`!4`#@0``!30````
M````$``5`-T#``#L%0```````!``#`#L`P``4%X``%,````2``P`*0,``*`H
M```K````$@`,`$0#``"`'0``&0$``!(`#``B!```(&$``'$"```2``P``00`
M`#`B```D!```$@`,``!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!L
M<V5E:P!G971P:60`<W1R8VUP`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``<W1R
M<F-H<@!C;&]S961I<@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E
M;@!V9G!R:6YT9@!S=')C:'(`7U]D97)E9VES=&5R7V9R86UE7VEN9F]?8F%S
M97,`<F5A9&QI;FL`7U]C>&%?9FEN86QI>F4`97AI=`!?251-7W)E9VES=&5R
M5$U#;&]N951A8FQE`')E860`7U]R96=I<W1E<E]F<F%M95]I;F9O7V)A<V5S
M`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E<G)N;U]L;V-A=&EO;@!M:V1I<@!?
M7VQS=&%T7W1I;64V-`!M96UC<'D`<W1R;&5N`&=E='5I9`!097)L7W-Y<U]T
M97)M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L7V%T
M9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O
M86M?;F]C;VYT97AT`%]F:6YI`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L
M86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`
M4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E
M`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P
M`'-T<F-P>0!R96%D9&ER`'-T<G1O:P!S=')D=7``<'1H<F5A9%]A=&9O<FL`
M<W!R:6YT9@!?7VQI8F-?<W1A<G1?;6%I;@!S;G!R:6YT9@!?7U]E;G9I<F]N
M`%]?<W1A8VM?8VAK7V9A:6P`;&EB<&5R;"YS;P!L:6)C+FUU<VPM>#@V+G-O
M+C$`7W-T87)T7V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-U
M<G)E;G1?97AE8U]P<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P7VQI
M8G!A=&@`<&%R7VUK=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!84U])
M;G1E<FYA;'-?4$%27T)/3U0`<VAA7W5P9&%T90!M>5]P87)?<&P`<&%R7V)A
M<V5N86UE`%]?8G-S7W-T87)T`'!A<E]D:64`<VAA7VEN:70`<&%R7V1I<FYA
M;64`<&%R7VEN:71?96YV`%]E9&%T80!P87)?9FEN9'!R;V<`<VAA7V9I;F%L
M`%]E;F0`<&%R7V-L96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/
M4D4``.3-```(````Z,T```@```#`SP``"````,S/```(````U,\```@`````
MT```"````!#0```(````Q,\```8"``#(SP``!@,``-#/```&&@``V,\```X>
M``#<SP``!B(``.#/```&)0``Y,\```8I``#HSP``!BP``.S/```&,```\,\`
M``8T``#TSP``!C8``/C/```&.```_,\```8\``#HS@``!P$``.S.```'!```
M\,X```<%``#TS@``!P8``/C.```'!P``_,X```<(````SP``!PD```3/```'
M"@``",\```<,```,SP``!PT``!#/```'#@``%,\```</```8SP``!Q```!S/
M```'$0``(,\```<2```DSP``!Q,``"C/```'%```+,\```<5```PSP``!Q8`
M`#3/```'%P``.,\```<8```\SP``!QD``$#/```'&P``1,\```<<``!(SP``
M!QT``$S/```''P``4,\```<@``!4SP``!R$``%C/```'(P``7,\```<D``!@
MSP``!R<``&3/```'*```:,\```<J``!LSP``!RL``'#/```'+0``=,\```<N
M``!XSP``!R\``'S/```',0``@,\```<R``"$SP``!S,``(C/```'-0``C,\`
M``<W``"0SP``!SD``)3/```'.@``F,\```<[``"<SP``!ST``*#/```'/@``
MI,\```<_``"HSP``!T```*S/```'00``L,\```="``"TSP``!T,``+C/```'
M1```O,\```=&````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(/L#(/$#,,```````````#_LP0```#_HP@`````````_Z,,````:`````#I
MX/____^C$````&@(````Z=#_____HQ0```!H$````.G`_____Z,8````:!@`
M``#IL/____^C'````&@@````Z:#_____HR````!H*````.F0_____Z,D````
M:#````#I@/____^C*````&@X````Z7#_____HRP```!H0````.E@_____Z,P
M````:$@```#I4/____^C-````&A0````Z4#_____HS@```!H6````.DP____
M_Z,\````:&````#I(/____^C0````&AH````Z1#_____HT0```!H<````.D`
M_____Z-(````:'@```#I\/[___^C3````&B`````Z>#^____HU````!HB```
M`.G0_O___Z-4````:)````#IP/[___^C6````&B8````Z;#^____HUP```!H
MH````.F@_O___Z-@````:*@```#ID/[___^C9````&BP````Z8#^____HV@`
M``!HN````.EP_O___Z-L````:,````#I8/[___^C<````&C(````Z5#^____
MHW0```!HT````.E`_O___Z-X````:-@```#I,/[___^C?````&C@````Z2#^
M____HX````!HZ````.D0_O___Z.$````:/````#I`/[___^CB````&CX````
MZ?#]____HXP```!H``$``.G@_?___Z.0````:`@!``#IT/W___^CE````&@0
M`0``Z<#]____HY@```!H&`$``.FP_?___Z.<````:"`!``#IH/W___^CH```
M`&@H`0``Z9#]____HZ0```!H,`$``.F`_?___Z.H````:#@!``#I</W___^C
MK````&A``0``Z6#]____H[````!H2`$``.E0_?___Z.T````:%`!``#I0/W_
M__^CN````&A8`0``Z3#]____H[P```!H8`$``.D@_?___Z/`````:&@!``#I
M$/W___^CQ````&AP`0``Z0#]____H\@```!H>`$``.GP_/___Z/,````:(`!
M``#IX/S___^CT````&B(`0``Z=#\____H]0```!HD`$``.G`_/___Z/8````
M:)@!``#IL/S___^CW````&B@`0``Z:#\____H^````!HJ`$``.F0_/___Z,`
M`0``9I#_HPP!``!FD/^C%`$``&:0```````````/"P\+#PMFD&:09I!FD&:0
MC4PD!(/D\/]Q_%6)Y5>)SU93Z'<"``"!PQ6[``!1@^PLBT$$B474BT$(B470
M9:$4````B47DC4704(U%U%!1Z#S^__^+@R`!``"#Q`Q04/^S'`$``.C6_/__
MBX/L````@\00@#@`#X0A`0``BX/\````98L`@(CJ`@```XL'C7`#@\`$B77,
M/?___S\/AWT!``"#[`S!X`)0Z"+^__^+==2+/X/$$(G!B8-<`0``BP:)`8V#
M_*+__XE!!(N#-`$``(E!"(V#_Z+__XE!#(/_`0^.30$``(E-R(U&!(U1$(TT
MOBZ-M"8`````C;8`````BPB#P`2#P@2)2OPYQG7QBTW(@\<#@^P,C8,$3O__
MQP2Y`````&H`4?]US%#_LV`!``#HB?S__X/$((7`#X2/````@^P,_[-@`0``
MC7W@Z`W]__^)^HG&C8.XH?__Z)X"``"#Q!"%P'1^@^P,_[-@`0``Z"G^___H
M%/O__X/$$(M%Y&4K!10````/A;@```"-9?")\%E;7E]=C6'\P^AN_/__B8-@
M`0``A<`/A(T```"#[`Q0Z#?]__^+@_P```"#Q!!EBQ#&@K(%````Z;'^__^#
M[`S_LV`!``#HX?S__X/$$.E;____BX-8`0``A<!T$8/L#%#H-AT``(/$$.EG
M____B?J-@VVA___H\0$``(F#6`$``(7`#X1,____Z])04(V#:*'___^S!`$`
M`%#HO?K__[\$````Z=C^__^#[`QJ`>A9_/__Z*5-```Q[8G@@^3P4%#H````
M`($$)/*W``!0Z`````!3Z#$```"!P\^X``"#[!"+1"08:@"-4`3_L_````#_
ML_@```!2_S#_L^0```#HU_O__X/$*%O#BQPDPV:09I!FD&:09I!FD&:0Z$4!
M``"!PH>X``"-BC@!``"-@C@!```YR'0=BX+T````A<!T$U6)Y8/L%%'_T(/$
M$,G#+HUT)@##C;0F`````.@%`0``@<)'N```58GE4XV*.`$``(V".`$``(/L
M!"G(B</!Z!_!^P(!V-'X=!2+DA`!``"%TG0*@^P(4%'_TH/$$(M=_,G#+HVT
M)@````"058GE4^A5____@</SMP``@^P$@+LX`0```'5#BY,,`0``A=)T$8/L
M#/^S)`$``.AU_/__@\00Z#7___^+@P`!``"%P'02@^P,C8.HX___4.A,_/__
M@\00QH,X`0```8M=_,G#+HVT)@`````NC70F`%7H`````%J!PH:W``")Y5/H
MV?[__X'#=[<``(/L!(N#%`$``(7`=!F-@SP!``!2:@!0C8.HX___4.@"_/__
M@\00BUW\R>GV_O__BQ0DPV:058G!5U93Z)/^__^!PS&W``"#[!R)5"0(BX,(
M`0``BQ"%T@^$FP````^V`83`=`0\/755,>V+,H7V=#R)5"0,B?")UHE,)`2)
MQXVT)@````"#[`15_W0D#%?H,OG__X/$$(7`=0:`/"\]=#6+?@2#Q@2%_W7;
MB?Z#Q!R)\%M>7UW#C;0F`````(G-#[9%`8/%`83`=`0\/77Q*<WKF(UV`(M4
M)`R)^(GWB<:+1"0(*=>-="X!P?\"B3B#Q!R)\%M>7UW#,?;KL"Z-M"8`````
MD%93Z,?]__^!PV6V``"![*P```!EBS44````B;0DI````(G&C40D%%!6Z%+Z
M__^#Q!"%P'4[BU0D'('B`/```('Z`$```'0(@?H`H```=2.#[`AJ`E;HEO?_
M_X/$$(7`#Y3`#[;`ZPLNC;0F`````)`QP(N4))P```!E*Q44````=0F!Q*0`
M``!;7L/HD4H``%575E/H-?W__X'#T[4``('LO````&6+-10```")M"2L````
MB<:%]G0%@#X`=2*+A"2L````92L%%`````^%-P$``('$O````%M>7UW#C78`
M@^P,5NC']O__@\00B<>%P'3,@^P,5^AE]___@\00A<`/A+H```"`>!,NC5`3
M=1&`>@$`=-TNC;0F`````(UV`(!X$RX/A+8```")5"0,@^P,5NBI^?__BU0D
M'(G%B10DB50D'.B7^?__C40%`HD$).A+]___BU0D'(G%C8,DH?__4E905>A&
M^?__@\08C40D)%!5Z,CX__^#Q!"#^/]T$(M$)"PE`/```#T`0```='"#[`Q5
MZ/?V__^#Q!"#[`Q5Z,OX__^#Q!"#[`Q7Z*_V__^#Q!"%P`^%2O___XUT)@"#
M[`Q7Z#?W__^)-"3H7_C__X/$$.GE_O__C;0F`````(!Z`2X/A4#___^`>@(`
M#X3^_O__Z3'___^-M"8`````B>CHB?[__^N3Z!-)``!FD%6)Q3'`5U93Z+'[
M__^!PT^T``"#[#B`.CUEBS44````B70D*(G6#Y3``<96Z)_X__^#Q!")1"0$
MC50D&(GHZ-W\__^%P`^$)0$``(/L#(G'4.AZ^/__BTPD%(/$$#G(#X/K````
MBT0D&,'@`HE$)`B+@P@!``")!"0/MD4`A,`/A+L!```\/0^$LP$``(GHD`^V
M4`&#P`&$TG0%@/H]=?`IZ(L,)(M\)`B#[`R+5"00`SF-1!`"4.C4]?__@\00
MB0>%P'1JBPPDBWPD"(L!C4T!BQ0X#[9%`(@"/#UT-83`=2+K+^L:+HVT)@``
M```NC;0F`````"Z-M"8`````9I`\/70/#[8!@\(!@\$!B`*$P'7MQ@(],<`N
MC;0F``````^V#`:(3`(!@\`!A,EU\8M$)!QE*P44````#X43`0``@\0L6UY?
M7<,NC;0F`````#'`+HVT)@````"-M@`````/MA0&B!0'@\`!A-)U\NN_BX,(
M`0``BQ")!"2+.H7_#X3"````,?\NC;0F`````)")^(/'`8L,NH7)=?2-!(4,
M````BXM4`0``A<EU8XE4)`R#[`Q0QX-4`0```0```.C,]/__@\00B<&%P`^$
M7O___XT$O0````"#[`2)1"0,4(M4)!1248E,)!SHL?3__XM$)!"+3"0<@\00
MB0C'1+D$`````(E\)!CI;/[__XUV`(/L"%!2Z*;S__^)P8M$)!"#Q!")"(7)
M#X0"____C02]`````(E$)`CKPHVV`````#'`Z5O^__^X"````#'_Z5#____H
MN48``"Z-M"8`````5E/H5_G__X'#];$``(/L!(V#=.'__XNS_````%"-@RJA
M____LQ@!``!09?\VZ.[U__]8C8/9HO__6FH`4%"-@\1A__]0C8-&H?__4&7_
M-NA,\___@\0D6U[#C;8`````4^CX^/__@<.6L0``@^P(C8-TX?__4(V#*J'_
M__^S&`$``%"+@_P```!E_S#HC_7__X/$&%O#+HVT)@````!FD%575E.![``0
M``"##"0`@>P`$```@PPD`(/L'.B>^/__@<,\L0``9:$4````B80D#"```#'`
MZ/;R__^#[`R-DUNA__]24(V#7Z'__U!H`1```(UT)"96Z)7R__^#Q""-4`&!
M^@$0```/A[/U__^#^/\/A)H```"#[`1H`!```(V\)!,0``!75N@4]/__@\00
MB<6%P'A[@^P,C4`!4.CO\O__@\00B<:%P'1F.?AS"XT$*#G'#X)G]?__.?=R
M0X']`1````^'5_7__X/L!%575NC<]/__Q@0N`(/$$(N$)`P@``!E*P44````
M=2F!Q!P@``")\%M>7UW#+HVT)@````"-!"\YQG.VZ13U__^-="8`,?;KQ^CX
M1```C;0F`````.G;_O__+HVT)@````"-=@!55U93@>P`$```@PPD`('LS```
M`.AU]___@<,3L```B[PDX!```&6++10```")K"2\$```BZPDY!```(U$)"R)
M1"04B<*-@VVA___HH/C__X/L"&HOB<97Z,/R__^#Q!"%P'0TC8-VH?__B?KH
M7_O__XGXBY0DO!```&4K%10````/A;P!``"!Q,P0``!;7E]=PXVV`````(/L
M#%7H+_+__UI9C8N#H?__B4PD%%%0Z*SS__^#Q!"-BX6A__^)Q8V#CJ+__XE$
M)!B%[727B7PD$(E,)!PNC;0F`````(UV`(!]```/A)8```"%]G01@^P(55;H
M&/'__X/$$(7`=%B#[`Q5Z)CS__^#Q!")QXU$!?\YQ7(5ZR8NC;0F`````)#&
M``"#Z`$YQ70%@#@O=/&#[`Q5Z&CS__^#Q!")QX/L#/]T)!SH5_/__X/$$(U$
M!P(]_P\``'99@^P(_W0D%&H`Z/OR__^#Q!")Q87`#X5N____BWPD$.GI_O__
M+HUT)@"%]G0%@#XN=!>_`0```(VK:Z'__^NG+HVT)@````!FD(!^`0!TL>OA
M+HVT)@````"#[`C_="08_W0D*%7_="0L:``0``"-K"38````5>CN[___@\0@
M@\`!/0`0```/AP_S__^#[`C_="0<5>@0\O__@\00A<`/A5S___^+1"0\)0#P
M```]`(````^%2/___X/L"&H!5>B6[___@\00A<`/A3+___^)ZHV#=J'__^B>
M^?__@^P,5>B5\/__@\00Z3#^___HF4(``"Z-M"8`````5E/H-_7__X'#U:T`
M`(/L#(MT)!AJ+U;H-/#__X7`C5`!#T7RB30DZ%3P__^#Q!1;7L,NC;0F````
M`(VV`````%93@>P`$```@PPD`(/L%.CJ]/__@<.(K0``98LU%````(FT)`P0
M``"+M"0@$```A?8/A)D```"`/@`/A)````"#[`Q6Z,?Q__^#Q!"-4`$QP('Z
M`!```'=;@^P(5HUT)!A6Z)GO__^)-"3HH?'__X/$$(U$!O\YQG(0ZQ.-="8`
MQ@``@^@!.?!T!8`X+W3Q@^P(:B]6Z';O__^#Q!"%P'0O.<9S`\8``(/L#%;H
MC^___X/$$(N4)`P0``!E*Q44````=2"!Q!00``!;7L.-=@"#[`R-@VNA__]0
MZ&'O__^#Q!#KT.AH00``C;0F`````%575NAA$0``@<:DK```4X/L+&6+'10`
M``")7"0<C5PD&(NN"`$``(V^AZ'__XG:B?CH.O7__X7`="^+5"08BT4`C020
MBU`$B1"%TG3@C78`BU`(@\`$B1"%TG7TB=J)^.@+]?__A<!UT8NN"`$``(V^
MD*'__XG:B?CH\O3__X7`=#>+5"08BT4`C020BU`$B1"%TG3@+HVT)@````"-
M=@"+4`B#P`2)$(72=?2)VHGXZ+OT__^%P'7)BZX(`0``C;Z8H?__B=J)^.BB
M]/__A<!T-XM4)!B+10"-!)"+4`2)$(72=.`NC;0F`````(UV`(M0"(/`!(D0
MA=)U](G:B?CH:_3__X7`=<F+K@@!``"-OJ&A__^)VHGXZ%+T__^%P'0WBU0D
M&(M%`(T$D(M0!(D0A=)TX"Z-M"8`````C78`BU`(@\`$B1"%TG7TB=J)^.@;
M]/__A<!UR8V&J*'__XN^"`$``(D$)(L$)(G:Z/[S__^%P'0TBU0D&(L'C020
MBU`$B1"%TG3@+HVT)@````"+4`B#P`2)$(72=?2+!"2)VNC*\___A<!US(NN
M"`$``(V^N*'__XG:B?CHL?/__X7`=#:+5"08BT4`C020BU`$B1"%TG3@+HVT
M)@````!FD(M0"(/`!(D0A=)U](G:B?CH>_/__X7`=<J-AFVA__^+O@@!``")
M1"0$BT0D!(G:Z%SS__^%P'0SBU0D&(L'C020BU`$B1"%TG3?C;8`````BU`(
M@\`$B1"%TG7TBT0D!(G:Z"GS__^%P'7-C8;$H?__B[X(`0``B40D#(M$)`R)
MVN@*\___A<!T,8M4)!B+!XT$D(M0!(D0A=)TWXUT)@"+4`B#P`2)$(72=?2+
M1"0,B=KHV?+__X7`=<^-ALZA__^+O@@!``")1"0(BT0D"(G:Z+KR__^%P'0Q
MBU0D&(L'C020BU`$B1"%TG3?C70F`(M0"(/`!(D0A=)U](M$)`B)VNB)\O__
MA<!USXNN"`$``(V^V*'__XG:B?CH</+__X7`=#6+5"08BT4`C020BU`$B1"%
MTG3@+HVT)@````"0BU`(@\`$B1"%TG7TB=J)^.@[\O__A<!URXNN"`$``(V^
M=J'__XG:B?CH(O+__X7`=#>+5"08BT4`C020BU`$B1"%TG3@+HVT)@````"-
M=@"+4`B#P`2)$(72=?2)VHGXZ.OQ__^%P'7)B=J-AN*A___HVO'__X7`=`N)
MPHM$)`CHJ_3__XG:C8;SH?__Z+[Q__^%P'0-B<*-A@6B___HC?3__XG:C880
MHO__Z*#Q__^)PH7`="N+1"0$Z''T__^+1"0<92L%%````'4SBP0D@\0LC98Q
MHO__6UY?7>E/]/__B=J-AB"B___H8O'__X7`=,V)PHM$)`SH,_3__^O`Z#T]
M```NC;0F`````(UT)@#H,`T```5WJ```@^P<98L5%````(E4)`R-5"0(C8#$
MH?__Z!GQ__^%P'0M#[80@/HP#Y3`A-(/E,()T(/P`0^VP(M4)`QE*Q44````
M=0Z#Q!S#C;8`````,<#KY>C0/```+HVT)@````"-M"8`````4^AH[___@<,&
MJ```@^P(C40D%(/L!%#_="08BX/H````_S#HJ.K__\<$)/\```#H/.O__RZ-
MM"8`````C70F`%575E.-G"0``/__@>P`$```@PPD`#G<=?*#["SH#>___X'#
MJZ<``&6++10```")K"0<``$`B<5J`FH`:@!5Z$WI__^#P/^#TO^)1"08BW0D
M&(G7B50D','_'S'X*?@QTB7__P``,?HQ^"GX&?J+?"0<*<:)="08&=>)?"0<
M@\00C70D%(7_#XC,````C70F`&H`_W0D$/]T)!!5Z/#H__^#Q!`AT(/X_P^$
MP@```(/L!&@(``$`5E7HL^K__X/$$(/X_P^$F````(/X!W9BC40&^#GP<EJ-
M/2@!``#K&2Z-M"8`````+HVT)@````!FD(/H`3GP<CF+$(M(!#,4'S-,'P0)
MRG7I*?"9`T0D"!-4)`R+C"0<``$`92L-%````'5=@<0L``$`6UY?7<.-=@"!
M1"0(``#__XM4)`B#5"0,_XM,)`R)T(G*-0``___WT@G0#X4X____N/____^)
MPNNQ@^P,C8-`HO__4.A0_O__@^P,C8,SHO__4.A!_O__Z/TZ```NC;0F````
M`(UT)@!3Z)CM__^!PS:F``"#[`CHO.K__X/L#%#H,^G__X/$$(7`=`*+`(/$
M"%O#+HUT)@!55U93Z&7M__^!PP.F``"#["QEBRT4````B6PD'(ML)$"-5"08
MC;M,HO__B?CHGN[__X7`=`>`.`")QG4CBT0D'&4K!10```!U;8GJ@\0LB?A;
M7E]=Z5;Q__^-M@````"#[`Q5Z!?J__^)-"2)1"0<Z`OJ__^+5"0<C40"`HD$
M).B[Y___B30DB<*-@X.A__]0C8..HO__55!2B50D+.BMZ?__@\0@BU0D#(M$
M)!QE*P44````=)7H!3H``(UT)@!55U93Z*7L__^!PT.E``"!["P!``"+A"1`
M`0``C7PD((GZB40D#(V+8Z+__V8/;L&-BQNB__]EH10```")A"0<`0``C8-K
MH?__9@]NR8V+_J'__\>$)+@`````````QX0DY`````````#'A"3(````````
M`&8/;M"-@W"B__]F#V+"9@]NV(V#:*+__V8/;N!F#V++C8-YHO__9@_6A"2P
M````9@]NP8V+=*+__V8/;NAF#V+$C8-MH?__9@]LP8E$)!@/$80DU````&8/
M;L%F#V+%9@_6A"3`````Z"_M__^%P'0)@#@`#X5Z!```Z.WH__^#[`Q0Z&3G
M__^#Q!"%P`^$&0(``(LHA>T/A`\"``"#[`Q5Z*;H__^#Q!"#[`R-1``!4.A6
MYO__@\00B<8/MD4`B70D"(3`=#B-BX*B__^)?"0$B?>)SHVT)@````"#[`0/
MML"#Q0%05E>#QP+H+.C__P^V10"#Q!"$P'7ABWPD!(VT)-````"-@P6B___K
M$(VV`````(M&!(/&!(7`="Z)^NAW[/__B<6%P'3I@#@`=.3H-^W__X7`=-N#
M[`Q5Z#KF__^#Q!")Q87`=3&0C;0DL````(LNA>UT(X!]```/A#D!``")Z.@"
M[?__A<`/A0(!``"+;@2#Q@2%[77=@^P,5>C'Y___6O]T)!2)QNB[Y___C;0&
M!`0``(DT).ALY?__B40D%(G!6(V#AZ+__UK_="004(V#A:'__XE$)!A0C8.,
MHO__58G-4%'H3N?__X/$&&C``0``5>CPYO__@\00@_C_=1#HT^;__XL`@_@1
M#X72`@``@^P(5_]T)!#HZ^;__X/$$(G%A<!U%(M$)#`E`/```#T`0```#X0`
M`0``_W0D!(M$)!#_,(V#0*/__U"+@^@```#_,.@0YO__@\00,?8NC;0F````
M`(UV`(N$)!P!``!E*P44````#X4H!```@<0L`0``B?!;7E]=PXVT)@````"#
M[`R#Q@15Z/SD__^#Q!")Q87`#X3&_O__Z>K^__\NC;0F`````&:0,>WIV?[_
M_RZ-M"8`````D(VT),`````NC;0F`````)"+!H7`=!J)^NC3ZO__A<!T!8`X
M`'4RBT8$@\8$A<!UYH/L#(VK7*+__VH-Z"#D__^#Q!")1"0(B<:X4P```.G(
M_?__+HUT)@"#[`R#Q@10Z&SD__^#Q!"%P'2EB<7I?_W__XM$)#B)1"00Z$'F
M__\Y1"00#X7I_O__BT0D,"7_`0``/<`!```/A=7^__^#[`Q6Z+KC__^)^HG&
MC8-7HO__Z#OJ__^#Q!"%P`^$L`$``(/L"%"+1"08_S#H,?'__XE$)""#Q!"%
MP`^$D@$``(/L#/]T)!SHMN7__X/$$(G"@_@#=DR#[`B-@Y6B__]0BT0D'(U$
M$/R)5"0H4.@`X___@\00A<!U*8M4)!R#^@0/A&$"``"+1"00@'P0^R\/A%("
M```NC;0F`````"Z-="8`B?J-N\2A__^)^.BAZ?__A<`/A"D!```/M@"$P`^$
M'@$``#PP#X06`0``C9,QHO__B?B-N]FB___H4^S__^A^XO__@^P(5U"-@[FB
M____="08_W0D&%!6Z-3D__^#Q""-@\>B__^)1"0,ZS(NC70F`.A;Y/__@S@1
M=3GH0>+__X/%`8/L!%=54/]T)!C_="08_W0D)%;HEN3__X/$((/L"&C``0``
M5N@UY/__@\00@_C_=+V#[`S_="00Z#'D__^+1"0HB?+HQNO__XDT).@.^O__
M@\00Z8;]__^#[`Q0_W0D%(M$)"#_,(V#!*/__U"+@^@```#_,.ADX___@\0@
MZ4_]__^-="8`@^P,4(E$)!3HR_G__XM$)!2)!"3H;^+__X/$$(G&Z37]__\N
MC70F`(M$)`R+`(E$)!#I7_[__Y"#[`AJ`/]T)!SH4N+__X/$$(7`#X31_O__
MB40D#.B^]___B40D$(E4)!2%T@^(N/[__X/`]FH`@]+_4E"+3"0848E,)!SH
M)N'__X/$#&H&C80D]0```%"+3"0848E,)!SHZ^+__X/$$(M,)`R#^`8/A>P`
M``"!O"3M`````$-!0P^%9/[__V:!O"3Q````2$4/A53^__]J`(M$)!2+5"08
M@\#.@]+_4E!1B4PD'.B^X/__@\0,:BB-O"3[````5XM,)!A1Z(?B__^#Q!"#
M^"@/A8P```#&A"0;`0```(V#V:+__X/L"%"-@ZJB__]7_W0D&/]T)!A05NCS
MXO__@\0@Z6[^__^+1"0,BU`$A=(/A*S]__^#[`Q2B50D'.C_XO__@\00@_@#
M#X:3_?__@^P(C8N:HO__48M4)!B-1`+\4.A+X/__@\00BU0D#(7`#T54)!")
M5"00Z63]___H`#,``(/L#(V#GZ+__U#H,/;__U575E/HE>7__X'#,YX``(/L
M+(U\)!B)^F6+-10```")="0<B[/\````98LN#[9%:(A%:8V#J*'__^C"YO__
MA<!T"8`X,0^$10$``.A`\?__98LNC8/8HO__:@-J`5!5Z+S@__^#Q!")Q87`
M="F#[`2-@]JB__]0BT4,_S!E_S;HO.#__XM%#(/$$(L`]D`*0`^%0@$``(V#
MWZ+__VH#:@%09?\VZ'?@__^#Q!")Q87`="F)^HV#=J'__^A!YO__A<`/A-D`
M``"#[`10BT4,_S!E_S;H:.#__X/$$(/L!(V#X:+__VH!4&7_-NC!WO__@\0,
MC9/VHO__4E!E_S;H/N#__V6+!HGZQD!I`(V#;:'__^CJY?__@\00B8-8`0``
MA<!T/8/L"&C``0``4.C_X/__@\00C5`!@_H!=@F#^!$/A:<```"+1"0<92L%
M%`````^%U````(/$+%M>7UW#9I"#[`S_LUP!``#H@O?__X/$$(F#6`$``(7`
M=:B#[`R-@Y2C__]0Z&;>__^-M@````"`>`$`#X2Y_O__Z:S^__^0Z#OK__^+
M50R+"F6+%H7`=%^#[`10B40D%%%2Z(#?__^+1"0<B00DZ'3@__^#Q!#I!___
M_XUT)@"#[`A09?\VZ&S>__^#Q!#IJO[__U"+@UP!``#_LU@!``#_,(V#N*/_
M_U#HZ=W__RZ-M"8`````D(N#7`$``(/L!/\P45+H'M___X/$$.FQ_O__Z,(P
M``"05U93Z&;C__^!PP2<``"#[!!EBS44````B70D#(MT)""-5"0(C8/$H?__
MZ*'D__^%P'0;#[80A-(/E,"`^C`/E,((T'4)A?9T!8`^`'4:BT0D#&4K!10`
M``!U98/$$%M>7\.-M@````"#[`Q6Z/_M__^)QUA::B]7Z`/>__^%P(U0`0]%
M^HD\).@CWO__@\0,C9.'HO__:@124.C!W?__@\00A<!UJ(M$)`QE*P44````
M=0V#Q!")\%M>7^EPY?__Z/PO``"+!"3#BS0DPV:0D.CUX___@<(WFP``55=6
M4X'L#`,``&6+#10```")C"3\`@``B<&-?"1PC40D>(E\)#"-K"3X````B4PD
M((UQ.)"+?@0QVXL.QT#\`````&8/;L.#P!"#Q@B)^V8/;L\/R8E(Z,'K"&8/
M8LC![QB)V3';9@]O^8E\)!!F#V[3B5PD!&8/;L$QVV8/8L)F#W/W&&8/;MN)
M#"1F#V^2E.'__V8/<_$(B5PD%&8/V\)F#V[79@]BTV8/;YJDX?__9@_KPF8/
M;]=F#]O39@_KPF8/;Y*TX?__9@_;RF8/Z\%F#]9`\#GH#X57____BWPD,(M,
M)""-A"38````9@]OA"2`````9@]OHH3A__]F#V^4))````"!QV@"``!F#V^,
M)*`````NC;0F`````(VT)@````#S#V\H9@]OV68/;TC8@\`09@_O0(AF#^_I
M9@_OQ68/;^AF#W/P`68/<]4?9@_KQ68/V\0/*4`(9@]OPF8/;],Y^'6]\P]^
M`68/;XJDX?__9@]O^/,/?D$(9@]OUV8/UGPD(&8/;]CS#WY!$&8/<_(%9@_6
M7"0P9@]OX/,/?D$89@_6)"1F#V_H\P]^02!F#]9L)$!F#V_P9@]OPF8/;]=F
M#W/2&V8/UG0D4&8/;[*DX?__9@_KPF8/;Y+$X?__9@_;P?,/?DPD<&8/U$PD
M4&8/U,IF#V_49@_OU68/U,%F#V_*9@]OTV8/V\MF#W/R'F8/[\UF#]3!9@]O
MBJ3A__]F#]O!9@]ORF8/;U0D,&8/;^AF#W/2`F8/<_4%9@_KRF8/;]1F#V^B
MQ.'__V8/V_%F#^_69@]OVO,/?E0D>&8/U%0D0&8/V]]F#^\<)&8/U-1F#V^B
MI.'__V8/U--F#V_=9@]OZ&8/<]4;9@_KW68/;VPD(&8/U-IF#V^2I.'__V8/
M<]4"9@_;VF8/;]=F#V^ZQ.'__V8/<_(>9@_KU?,/?JPD@````&8/U"PD9@_O
MRF8/V^)F#]O(9@_4[V8/;_MF#^_.9@]SUQMF#]3I9@]ORV8/<_$%9@_KS_,/
M?KPDB````&8/U,UF#V^JI.'__V8/U/=F#V^ZQ.'__V8/V\UF#V_H9@]S]1YF
M#W/0`F8/U/=F#^O%9@]O^68/;ZJDX?__9@_OT&8/<]<;9@_;TV8/V^AF#^_4
M9@_4\F8/;]%F#W/R!68/Z]=F#]369@]OLJ3A__]F#]O69@]O\V8/<_8>9@]S
MTP)F#V_^9@]OLJ3A__]F#^O[\P]^G"20````9@_OQV8/V_=F#]3<9@]OHL3A
M__]F#]O!9@_OQ68/U-QF#V_B9@_4V&8/<]0;9@]OPF8/<_`%9@_KQ&8/;^%F
M#W/T'F8/<]$"9@_4PV8/;YJDX?__9@_;PV8/;]QF#V^BI.'__V8/Z]GS#WZ,
M))@```!F#^_[9@_;XV8/U.EF#V^*Q.'__V8/V_IF#^_^9@_4Z68/;\AF#]3O
M9@]S\05F#V_X9@]SUQMF#^O/9@_4S68/;ZJDX?__9@_;S68/;^IF#W/U'F8/
M<]("9@]O_68/;ZJDX?__9@_K^O,/?I0DH````&8/[]]F#]OO9@_4UF8/;[+$
MX?__9@_;V&8/[]QF#]369@]O\68/U-IF#W/6&V8/;]%F#W/R!68/Z]9F#V_P
M9@]S]AYF#W/0`F8/U--F#V^:I.'__V8/Z_#S#WZ$)*@```!F#^_^9@_;TV8/
MV]YF#]3@9@]O@L3A__]F#]OY9@_O_68/U.!F#V_"9@_4YV8/<_`%9@]O^F8/
M<]<;9@_KQV8/U,1F#V^BI.'__V8/V\1F#V_A9@]S]!YF#W/1`F8/;_QF#V^B
MI.'__V8/Z_GS#WZ,)+````!F#^_W9@_;YV8/U.EF#V^*Q.'__V8/V_)F#^_S
M9@_4Z68/;\AF#]3N9@]S\05F#V_P9@]SUAMF#^O.9@]O\F8/<_8>9@]ST@)F
M#]3-9@]OJJ3A__]F#^OR\P]^E"2X````9@_O_F8/V\UF#]ON9@_4VF8/;Y+$
MX?__9@_;^&8/[_QF#]3:9@]OT68/U-]F#W/R!68/;_EF#W/7&V8/Z]=F#V_X
M9@]S]QYF#W/0`F8/U--F#V^:I.'__V8/Z_CS#WZ$),````!F#^_W9@_;TV8/
MV]]F#]3@9@]O@L3A__]F#]OQ9@_O]68/U.!F#]3F9@]O\F8/<_8%9@]OQF8/
M;_)F#W/6&V8/Z\9F#V_Q9@]S]AYF#W/1`F8/U,1F#V^BI.'__V8/Z_'S#WZ,
M),@```!F#^_^9@_;Q&8/V^9F#]3I9@]OBL3A__]F#]OZ9@_O^V8/U.EF#V_(
M9@_4[V8/<_$%9@]O^&8/<]<;9@_KSV8/U,UF#V^JI.'__V8/V\UF#V_J9@]S
M]1YF#W/2`F8/;_UF#V^JI.'__V8/Z_KS#WZ4)-````!F#^_W9@_;[V8/U-IF
M#V^2Q.'__V8/V_!F#^_T9@_4VF8/;]%F#]3>9@]S\@5F#V_Q9@]SUAMF#^O6
M9@]O\&8/<_8>9@]ST`)F#]339@]OFJ3A__]F#^OP\P]^A"38````9@_O_F8/
MV]-F#]O>9@_4X&8/;X+$X?__9@_;^68/[_UF#]3@9@]OPF8/U.=F#W/P!68/
M;_IF#W/7&V8/Z\=F#]3$9@]OHJ3A__]F#]O$9@]OX68/<_0>9@]ST0)F#V_\
M9@]OHJ3A__]F#^OY\P]^C"3@````9@_O]V8/V^=F#]3I9@]OBL3A__]F#]OR
M9@_O\V8/U.EF#V_(9@_4[F8/<_$%9@]O\&8/<]8;9@_KSF8/;_)F#W/V'F8/
M<]("9@_4S68/;ZJDX?__9@_;S68/;^YF#V^RI.'__V8/Z^KS#WZ4).@```!F
M#^_]9@_;]68/U-IF#V^2Q.'__V8/V_AF#^_\9@_4VF8/;]%F#]3?9@]S\@5F
M#V_Y9@]SUQMF#^O79@]O^&8/<_<>9@]ST`)F#]339@]OFJ3A__]F#^OX\P]^
MA"3P````9@_O[V8/V]-F#]O?9@_4X&8/;X+$X?__9@_;Z68/[^YF#]3@9@]O
MPF8/U.5F#W/P!68/;^IF#W/5&V8/Z\5F#V^JI.'__V8/U,1F#V^BI.'__V8/
MV\1F#V_A9@]S]!YF#W/1`F8/Z^'S#WZ,)/@```!F#^_\9@_;[&8/U/%F#V^*
MQ.'__V8/V_IF#^_[9@_4\68/;\AF#]3W9@]S\05F#V_X9@]SUQMF#^O/9@]O
MNJ3A__]F#]3.9@]OLJ3A__]F#]O.9@]O\F8/<_8>9@]ST@)F#^O69@]O]/,/
M?J0D``$``&8/[_)F#]OZ9@_4XV8/;YK$X?__9@_;\&8/[_5F#]3C9@]OV68/
MU.9F#W/3&V8/;_%F#W/V!68/Z]YF#V^RI.'__V8/V]YF#]3C9@]OV&8/<_,>
M9@]ST`)F#]OT9@_KV/,/?H0D"`$``&8/[]-F#]3%9@]OJL3A__]F#]O19@_O
MUV8/U,5F#]3"9@]OUF8/<_(%9@]OZF8/;]9F#W/2&V8/Z]5F#V^JI.'__V8/
MV]5F#]3"9@]OT68/<_(>9@]ST0)F#]OH9@_KT68/;\MF#^_*9@_OX68/;XJD
MX?__9@_;X?,/?HPD$`$``&8/U,]F#V^ZU.'__V8/U,]F#]3,9@]OY68/<_0%
M9@]O_&8/;^5F#W/4&V8/Z^=F#V^ZI.'__V8/V^=F#]3,9@]OY_,/?KPD&`$`
M`&8/UDPD$&8/;\YF#W/6`F8/VV0D$&8/<_$>9@_KSF8/;[+4X?__9@_4]V8/
M;[JDX?__9@_;WV8/U-YF#V_R9@_O\68/[\9F#V_T9@_;QV8/<_8%9@]O_&8/
M<]<;9@_4PV8/;]]F#^O>9@]OLJ3A__]F#]O>9@]O\&8/;X*DX?__9@_4\V8/
M;YK4X?__9@_;QF8/;_YF#V_U9@]S]AYF#W/5`F8/Z^[S#WZT)"`!``!F#]3>
M9@]OLJ3A__]F#]O69@]O\V8/;UPD$&8/U/)F#V_19@_OU68/[]IF#V^2I.'_
M_V8/V]-F#V_89@_4UF8/<],;9@]O\&8/<_8%9@_KWF8/;[*DX?__9@_;WF8/
MU--F#V^:U.'__V8/;_)F#V^2I.'__V8/UG0D$&8/;_1F#W/4`F8/VU0D$&8/
M<_8>9@_KYO,/?K0D*`$``&8/U-YF#V^RI.'__V8/V\YF#V_S9@_4\68/;\UF
M#^_,9@]OV68/;XJDX?__9@_OWV8/;_IF#]O+9@]SUQMF#]3.9@]O\F8/;]]F
M#W/V!68/Z]YF#V^RI.'__V8/V]YF#]3+9@]OFM3A__]F#V_Y9@]OSF8/;_!F
M#W/V'F8/<]`"9@_;SV8/Z\;S#WZT)#`!``!F#]3>9@]OLJ3A__]F#]ON9@]O
M]&8/U.MF#V]<)!!F#^_P9@_OWF8/;[*DX?__9@_;WF8/;_%F#]3=9@]S]@5F
M#V_I9@]SU1MF#^ON9@]OLJ3A__]F#]ON9@]O\V8/;YJDX?__9@_4]68/;ZK4
MX?__9@_6="009@]O\F8/<]("9@_;7"009@]S]AYF#^O6\P]^M"0X`0``9@_4
M[F8/;[*DX?__9@_;YF8/;_5F#]3T9@]OX&8/[^)F#V_L9@]OHJ3A__]F#^_O
M9@_;Y68/;^MF#]3F9@]SU1MF#V_S9@]S]@5F#^ON9@]OLJ3A__]F#]ON9@]O
M]&8/;Z*DX?__9@_4]68/;ZK4X?__9@_;YF8/;_YF#V_Q9@]S]AYF#W/1`F8/
MZ\[S#WZT)$`!``!F#]3N9@]OLJ3A__]F#]O&9@]O]68/;VPD$&8/U/!F#V_"
M9@_OP68/[^AF#V^"I.'__V8/V\5F#V_L9@_4QF8/<]4;9@]O]&8/<_8%9@_K
M[F8/;[*DX?__9@_;[F8/;_!F#V^"I.'__V8/U/5F#V^JU.'__V8/UG0D$&8/
M;_-F#W/3`F8/VT0D$&8/<_8>9@_KWO,/?K0D2`$``&8/U.YF#V^RI.'__V8/
MV]9F#V_U9@_4\F8/;]%F#^_39@]OZF8/;Y*DX?__9@_O[V8/V]5F#V_H9@_4
MUF8/<]4;9@]O\&8/<_8%9@_K[F8/;[*DX?__9@_;[F8/U-5F#V^JU.'__V8/
M;_IF#V_69@]O]&8/<_8>9@]SU`)F#]O79@_KYO,/?K0D4`$``&8/U.YF#V^R
MI.'__V8/V\YF#V_U9@]O;"009@_4\68/;\MF#^_,9@_OZ68/;XJDX?__9@_;
MS68/;^IF#]3.9@]SU1MF#V_R9@]S]@5F#^ON9@]OLJ3A__]F#]ON9@_4S68/
M;ZK4X?__9@]O\68/;XJDX?__9@_6="009@]O\&8/<]`"9@_;3"009@]S]AYF
M#^O&\P]^M"18`0``9@_4[F8/;[*DX?__9@_;WF8/;_5F#V_L9@_4\V8/[^AF
M#V^:I.'__V8/[^]F#]O=9@]OZ68/U-YF#W/5&V8/;_%F#W/V!68/Z^YF#V^R
MI.'__V8/V^YF#V_S9@]OFJ3A__]F#]3U9@]OJM3A__]F#]O>9@]O_F8/;_)F
M#W/V'F8/<]("9@_KUO,/?K0D8`$``&8/U.YF#V^RI.'__V8/V^9F#V_U9@]O
M;"009@_4]&8/;^!F#^_B9@_O[&8/;Z*DX?__9@_;Y68/;^MF#]3F9@]SU1MF
M#V_S9@]S]@5F#^ON9@]OLJ3A__]F#]ON9@]O]&8/;Z*DX?__9@_4]68/;ZK4
MX?__9@_6="009@]O\68/<]$"9@_;9"009@]S]AYF#^O.\P]^M"1H`0``9@_4
M[F8/;[*DX?__9@_;QF8/;_5F#]3P9@]OPF8/[\%F#V_H9@]O@J3A__]F#^_O
M9@_;Q68/;^QF#]3&9@]SU1MF#V_T9@]S]@5F#^ON9@]OLJ3A__]F#]ON9@]O
M\&8/;X*DX?__9@_4]68/;ZK4X?__9@_;QF8/;_YF#V_S9@]S]AYF#W/3`F8/
MZ][S#WZT)'`!``!F#]3N9@]OLJ3A__]F#]O69@]O]68/;VPD$&8/U/)F#V_1
M9@_OTV8/[^IF#V^2I.'__V8/V]5F#V_H9@_4UF8/<]4;9@]O\&8/<_8%9@_K
M[F8/;[*DX?__9@_;[F8/U-5F#V^JU.'__V8/;_)F#V^2I.'__V8/UG0D$&8/
M;_1F#W/4`F8/VU0D$&8/<_8>9@_KYO,/?K0D>`$``&8/U.YF#V^RI.'__V8/
MV\YF#V_U9@_4\68/;\MF#^_,9@]OZ68/;XJDX?__9@_O[V8/V\UF#V_J9@_4
MSF8/<]4;9@]O\F8/<_8%9@_K[F8/;[*DX?__9@_;[F8/U,UF#V^JU.'__V8/
M;_EF#V_.9@]O\&8/<_8>9@]ST`)F#]O/9@_KQO,/?K0D@`$``&8/U.YF#V^R
MI.'__V8/V]YF#V_U9@]O[&8/U/-F#^_H9@]OFJ3A__]F#^]L)!!F#]O=9@]O
MZ68/U-YF#W/5&V8/;_%F#W/V!68/Z^YF#V^RI.'__V8/V^YF#V_S9@]OFJ3A
M__]F#]3U9@]OJM3A__]F#]9T)!!F#V_R9@]ST@)F#]M<)!!F#W/V'F8/Z];S
M#WZT)(@!``!F#]3N9@]OLJ3A__]F#]OF9@]O]68/U/1F#V_@9@_OXF8/;^QF
M#V^BI.'__V8/[^]F#]OE9@]OZV8/U.9F#W/5&V8/;_-F#W/V!68/Z^YF#V^R
MI.'__V8/V^YF#V_T9@]OHJ3A__]F#]3U9@]OJM3A__]F#]OF9@]O_F8/;_%F
M#W/V'F8/<]$"9@_KSO,/?K0DD`$``&8/U.YF#V^RI.'__V8/V\9F#V_U9@]O
M;"009@_4\&8/;\)F#^_!9@_OZ&8/;X*DX?__9@_;Q68/;^QF#]3&9@]SU1MF
M#V_T9@]S]@5F#^ON9@]OLJ3A__]F#]ON9@]O\&8/;X*DX?__9@_4]68/;ZK4
MX?__9@_6="009@]O\V8/<],"9@_;1"009@]S]AYF#^O>\P]^M"28`0``9@_4
M[F8/;[*DX?__9@_;UF8/U.IF#V_19@_OTV8/[]=F#]O69@]O\&8/U-5F#W/V
M!68/;^AF#W/5&V8/Z^YF#V^RI.'__V8/V^YF#]359@]O[F8/;_1F#W/V'F8/
M<]0"9@_;ZF8/Z_1F#V^BU.'__V8/;_[S#WZT)*`!``!F#]3F9@]OLJ3A__]F
M#]O.9@]O]&8/;V0D$&8/U/%F#V_+9@_OSV8/[^%F#V^*I.'__V8/V\QF#]3.
M9@]O]68/<_8%9@]OYF8/;_5F#W/6&V8/Z^;S#WZT)*@!``!F#]3A9@]OBJ3A
M__]F#]OA9@]OR&8/<_$>9@]ST`)F#^O!9@]OBJ3A__]F#]O(#RE,)!!F#V^*
MU.'__V8/U,YF#V^RI.'__V8/V]YF#]399@]OSV8/[\AF#^_19@]OS&8/V]9F
M#W/Q!68/;_1F#W/6&V8/U--F#V^:I.'__V8/Z\[S#WZT)+`!``!F#]3*9@]O
MDJ3A__]F#]O*9@]OU68/<_(>9@]SU0)F#^OJ9@]OT&8/V]UF#^O59@_;U&8/
MV\-F#^O"9@]ODN3A__]F#]369@]OLJ3A__]F#]O^9@]O\68/U-=F#W/V!68/
M;[KDX?__9@_4T&8/;\9F#V_Q9@]SUAMF#^O&9@]O]&8/<_8>9@]SU`)F#]30
M9@]O@J3A__]F#^OF9@]OLJ3A__]F#]O09@_K[&8/;\1F#]O#9@_;Z68/V_1F
M#^OH\P]^A"2X`0``9@_41"009@_4QV8/;_IF#]3%9@]SUQMF#V_J9@]S]05F
M#^OO9@]ONJ3A__]F#]3H9@]O@J3A__]F#]OH9@]OP68/<_`>9@]ST0)F#^O(
M9@]OQ&8/V_EF#^O!9@_;PF8/V^=F#^O@\P]^A"3``0``9@_4V&8/;X+DX?__
M9@_4V&8/;\5F#]3<9@]S\`5F#V_E9@]SU!MF#^O$9@]OXF8/<_0>9@]ST@)F
M#]3#9@]OFJ3A__]F#^OB9@_KS&8/;]1F#]O#9@_;UV8/V\UF#]O<9@_KRO,/
M?I0DR`$``&8/U-9F#V^RY.'__V8/U-9F#V_P9@_4RF8/<]8;9@]OT&8/<_(%
M9@_KUF8/;[*DX?__9@_4T68/;XJDX?__9@_;T68/;\UF#W/Q'F8/<]4"9@_K
MZ68/;\QF#]OU9@_KS68/V^9F#]O(9@_KS/,/?J0DT`$``&8/U.=F#V^ZY.'_
M_V8/U.=F#V_Z9@_4X68/<]<;9@]ORF8/<_$%9@_KSV8/U,QF#V^BI.'__V8/
MV\QF#V_@9@]S]!YF#W/0`F8/;_QF#V^BI.'__V8/Z_AF#^OO9@]OQV8/V^=F
M#]O&9@_;ZF8/Z^CS#WZ$)-@!``!F#]389@]O@N3A__]F#]389@]OP68/U-UF
M#W/P!68/;^EF#W/5&V8/Z\5F#V_J9@]S]1YF#W/2`F8/U,-F#V^:I.'__V8/
MZ^IF#V_79@_;PV8/Z]5F#]O=9@_;T68/V_MF#^OZ\P]^E"3@`0``9@_4\F8/
M;Y+DX?__9@_4\F8/;]!F#]3W9@]S\@5F#V_X9@]SUQMF#^O79@_4UF8/;[*D
MX?__9@_;UF8/;_%F#W/V'F8/<]$"9@]O_F8/;[*DX?__9@_K^68/Z^]F#V_/
M9@_;]V8/V\MF#]OH9@_KZ?,/?HPDZ`$``&8/U.%F#V^*Y.'__V8/U.%F#V_*
M9@_4Y68/<_$%9@]OZF8/<]4;9@_KS68/U,QF#V^BI.'__V8/V\QF#V_@9@]S
M]!YF#W/0`F8/;^QF#V^BI.'__V8/Z^AF#V_'9@_;Y68/Z\5F#]O"9@_;_&8/
MZ_CS#WZ$)/`!``!F#]389@]O@N3A__]F#]389@]OP68/U-]F#W/P!68/;_EF
M#W/7&V8/Z\=F#V_Z9@]S]QYF#W/2`F8/U,-F#V^:I.'__V8/Z_IF#^OO9@]O
MUV8/V\-F#]O49@_;Z68/V]]F#^OJ\P]^E"3X`0``9@_4UF8/;[+DX?__9@_4
MUF8/;_!F#]3J9@]SUAMF#V_09@]S\@5F#^O69@]O\68/<_8>9@]ST0)F#]35
M9@]OJJ3A__]F#^OQ9@]OSV8/V]5F#^O.9@_;[F8/V\AF#]O]9@_K^?,/?HPD
M``(``&8/U.%F#V^*Y.'__V8/U.%F#V_*9@_4YV8/<_$%9@]O^F8/<]<;9@_K
MSV8/U,QF#V^BI.'__V8/V\QF#V_@9@]S]!YF#W/0`F8/;_QF#V^BI.'__V8/
MZ_AF#^OW9@]OQV8/V^=F#]O%9@_;\F8/Z_#S#WZ$)`@"``!F#]389@]O@N3A
M__]F#]389@_4WF8/;_%F#W/V!68/;\9F#V_Q9@]SUAMF#^O&9@]O\F8/<_8>
M9@]ST@)F#]3#9@]OFJ3A__]F#^OR9@]OUV8/V\-F#^O69@_;WF8/V]%F#]O[
M9@_K^O,/?I0D$`(``&8/U.IF#V^2Y.'__V8/U.IF#V_09@_4[V8/<_(%9@]O
M^&8/<]<;9@_KUV8/U-5F#V^JI.'__V8/V]5F#V_I9@]S]1YF#W/1`F8/;_UF
M#V^JI.'__V8/Z_EF#^OW9@]OSV8/V^]F#]O+9@_;\&8/Z_'S#WZ,)!@"``!F
M#]3A9@]OBN3A__]F#]3A9@]ORF8/U.9F#W/Q!68/;_)F#W/6&V8/Z\YF#V_P
M9@]S]AYF#W/0`F8/U,QF#V^BI.'__V8/Z_!F#V_'9@_;S&8/Z\9F#]OF9@_;
MPF8/V_QF#^OX\P]^A"0@`@``9@_4V&8/;X+DX?__9@_4V&8/;\%F#]3?9@]S
M\`5F#V_Y9@]SUQMF#^O'9@]O^F8/<_<>9@]ST@)F#]3#9@]OFJ3A__]F#]O#
M9@]OWV8/Z]IF#V^2I.'__V8/Z_-F#]O39@_;\68/;_IF#V_39@_;U&8/Z_+S
M#WZ4)"@"``!F#]3J9@]ODN3A__]F#]3J9@]OT&8/U.YF#W/R!68/;_!F#W/6
M&V8/Z]9F#V_Q9@]S]AYF#W/1`F8/U-5F#V^JI.'__V8/V]5F#V_N9@]OLJ3A
M__]F#^OI9@]ORV8/V_5F#^O-9@_;WF8/V\AF#^O+\P]^G"0P`@``9@_4W&8/
M;Z+DX?__9@_4W&8/;^)F#]399@]SU!MF#V_*9@]S\05F#^O,9@]OX&8/<_0>
M9@]ST`)F#]3+9@]OFJ3A__]F#^O@9@]OPV8/Z^QF#]O+\P]^G"0X`@``9@_;
MQ&8/V^H/*40D$&8/;\1F#]3?9@_;QF8/Z^AF#V^"Y.'__V8/U-AF#V_!9@_4
MW68/<_`%9@]OZ68/<]4;9@_KQ68/;^IF#W/U'F8/<]("9@_4PV8/;YJDX?__
M9@_;PV8/;]UF#V_L9@_KVF8/;Y*DX?__9@_KZV8/V]-F#]OI9@_;XF8/Z^7S
M#WZL)$`"``!F#]3N9@]OLN3A__]F#]3N9@]O\&8/U.QF#W/V!68/;^!F#W/4
M&V8/Z^9F#V^RI.'__V8/V^9F#V_^9@]O\68/<_8>9@]ST0)F#]3L9@]OHJ3A
M__]F#^O.9@_;_68/;_1F#^O9\P]^I"1(`@``9@_49"009@_;\68/V]@/*70D
M8&8/;_%F#]OR9@_KWF8/;[+DX?__9@_4YF8/;_=F#]3C9@]S]@5F#V_?9@]S
MTQMF#^O>9@]OLJ3A__]F#]O>9@_4XV8/;]AF#W/S'F8/<]`"9@_;]&8/Z]AF
M#V^"I.'__V8/[\MF#^_-9@_;R/,/?H0D4`(``&8/U,)F#V^2].'__V8/U,)F
M#V_69@_4P68/<_(%9@]OSF8/<]$;9@_KRF8/;Y*DX?__9@_;RF8/;^IF#V_7
M9@]S\AYF#W/7`F8/U,%F#^O79@]ORV8/;[KTX?__9@_;Z&8/[\IF#^_A9@]O
MBJ3A__]F#]OA\P]^C"18`@``9@_43"1@9@_4SV8/U,QF#V_E9@]S]`5F#V_\
M9@]OY68/<]0;9@_KYV8/;[JDX?__9@_;YV8/U,QF#V_G\P]^O"1@`@``9@_6
M3"009@]OSF8/<]8"9@_;9"009@]S\1YF#^O.9@]OLO3A__]F#]3W9@]ONJ3A
M__]F#]O?9@_4WF8/;_)F#^_Q9@_OQF8/;_1F#]O'9@]S]@5F#V_\9@]SUQMF
M#]3#9@]OWV8/Z]YF#V^RI.'__V8/V]YF#V_P9@]O@J3A__]F#]3S9@]OFO3A
M__]F#]O&9@]O_F8/;_5F#W/V'F8/<]4"9@_K[O,/?K0D:`(``&8/U-YF#V^R
MI.'__V8/V]9F#V_S9@]O7"009@_4\F8/;]%F#^_59@_OVF8/;Y*DX?__9@_;
MTV8/;]AF#]369@]STQMF#V_P9@]S]@5F#^O>9@]OLJ3A__]F#]O>9@_4TV8/
M;YKTX?__9@]O\F8/;Y*DX?__9@_6="009@]O]&8/<]0"9@_;5"009@]S]AYF
M#^OF\P]^M"1P`@``9@_4WF8/;[*DX?__9@_;SF8/;_-F#]3Q9@]OS68/[\QF
M#V_99@]OBJ3A__]F#^_?9@]O^F8/V\MF#W/7&V8/U,YF#V_R9@]OWV8/<_8%
M9@_KWF8/;[*DX?__9@_;WF8/U,MF#V^:].'__V8/;_EF#V_.9@]O\&8/<_8>
M9@]ST`)F#]O/9@_KQO,/?K0D>`(``&8/U-YF#V^RI.'__V8/V^YF#V_T9@_4
MZV8/;UPD$&8/[_!F#^_>9@]OLJ3A__]F#]O>9@]O\68/U-UF#W/V!68/;^EF
M#W/5&V8/Z^YF#V^RI.'__V8/V^YF#V_S9@]OFJ3A__]F#]3U9@]OJO3A__]F
M#]9T)!!F#V_R9@]ST@)F#]M<)!!F#W/V'F8/Z];S#WZT)(`"``!F#]3N9@]O
MLJ3A__]F#]OF9@]O]68/U/1F#V_@9@_OXF8/;^QF#V^BI.'__V8/[^]F#]OE
M9@]OZV8/U.9F#W/5&V8/;_-F#W/V!68/Z^YF#V^RI.'__V8/V^YF#V_T9@]O
MHJ3A__]F#]3U9@]OJO3A__]F#]OF9@]O_F8/;_%F#W/V'F8/<]$"9@_KSO,/
M?K0DB`(``&8/U.YF#V^RI.'__V8/V\9F#V_U9@]O;"009@_4\&8/;\)F#^_!
M9@_OZ&8/;X*DX?__9@_;Q68/;^QF#]3&9@]SU1MF#V_T9@]S]@5F#^ON9@]O
MLJ3A__]F#]ON9@]O\&8/;X*DX?__9@_4]68/;ZKTX?__9@_6="009@]O\V8/
M<],"9@_;1"009@]S]AYF#^O>\P]^M"20`@``9@_4[F8/;[*DX?__9@_;UF8/
M;_5F#]3R9@]OT68/[]-F#V_J9@]ODJ3A__]F#^_O9@_;U68/;^AF#]369@]S
MU1MF#V_P9@]S]@5F#^ON9@]OLJ3A__]F#]ON9@_4U68/;ZKTX?__9@]O^F8/
M;]9F#V_T9@]S]AYF#W/4`F8/V]=F#^OF\P]^M"28`@``9@_4[F8/;[*DX?__
M9@_;SF8/;_5F#V]L)!!F#]3Q9@]ORV8/[\QF#^_I9@]OBJ3A__]F#]O-9@]O
MZF8/U,YF#W/5&V8/;_)F#W/V!68/Z^YF#V^RI.'__V8/V^YF#]3-9@]OJO3A
M__]F#V_Q9@]OBJ3A__]F#]9T)!!F#V_P9@]ST`)F#]M,)!!F#W/V'F8/Z\;S
M#WZT)*`"``!F#]3N9@]OLJ3A__]F#]O>9@]O]68/;^QF#]3S9@_OZ&8/;YJD
MX?__9@_O[V8/V]UF#V_I9@_4WF8/<]4;9@]O\68/<_8%9@_K[F8/;[*DX?__
M9@_;[F8/;_-F#V^:I.'__V8/U/5F#V^J].'__V8/V]YF#V_^9@]O\F8/<_8>
M9@]ST@)F#^O6\P]^M"2H`@``9@_4[F8/;[*DX?__9@_;YF8/;_5F#V]L)!!F
M#]3T9@]OX&8/[^)F#^_L9@]OHJ3A__]F#]OE9@]OZV8/U.9F#W/5&V8/;_-F
M#W/V!68/Z^YF#V^RI.'__V8/V^YF#V_T9@]OHJ3A__]F#]3U9@]OJO3A__]F
M#]9T)!!F#V_Q9@]ST0)F#]MD)!!F#W/V'F8/Z\[S#WZT)+`"``!F#]3N9@]O
MLJ3A__]F#]O&9@]O]68/U/!F#V_"9@_OP68/;^AF#V^"I.'__V8/[^]F#]O%
M9@]O[&8/U,9F#W/5&V8/;_1F#W/V!68/Z^YF#V^RI.'__V8/V^YF#V_P9@]O
M@J3A__]F#]3U9@]OJO3A__]F#]O&9@]O_F8/;_-F#W/V'F8/<],"9@_KWO,/
M?K0DN`(``&8/U.YF#V^RI.'__V8/V]9F#V_U9@]O;"009@_4\F8/;]%F#^_3
M9@_OZF8/;Y*DX?__9@_;U68/;^AF#]369@]SU1MF#V_P9@]S]@5F#^ON9@]O
MLJ3A__]F#]ON9@_4U68/;ZKTX?__9@]O\F8/;Y*DX?__9@_6="009@]O]&8/
M<]0"9@_;5"009@]S]AYF#^OF\P]^M"3``@``9@_4[F8/;[*DX?__9@_;SF8/
M;_5F#]3Q9@]ORV8/[\QF#V_I9@]OBJ3A__]F#^_O9@_;S68/;^IF#]3.9@]S
MU1MF#V_R9@]S]@5F#^ON9@]OLJ3A__]F#]ON9@_4S68/;ZKTX?__9@]O^68/
M;\YF#V_P9@]S]AYF#W/0`F8/V\]F#^O&\P]^M"3(`@``9@_4[F8/;[*DX?__
M9@_;WF8/;_5F#V_L9@_4\V8/[^AF#V^:I.'__V8/[VPD$&8/V]UF#V_I9@_4
MWF8/<]4;9@]O\68/<_8%9@_K[F8/;[*DX?__9@_;[F8/;_-F#V^:I.'__V8/
MU/5F#]9T)!!F#V_R9@]ST@)F#]M<)!!F#W/V'F8/;ZKTX?__9@_KUO,/?K0D
MT`(``&8/U.YF#V^RI.'__V8/V^9F#V_U9@_4]&8/;^!F#^_B9@]O[&8/;Z*D
MX?__9@_O[V8/V^5F#V_K9@_4YF8/<]4;9@]O\V8/<_8%9@_K[F8/;[*DX?__
M9@_;[F8/;_1F#V^BI.'__V8/U/5F#V^J].'__V8/V^9F#V_^9@]O\68/<_8>
M9@]ST0)F#^O.\P]^M"38`@``9@_4[F8/;[*DX?__9@_;QF8/;_5F#V]L)!!F
M#]3P9@]OPF8/[\%F#^_H9@]O@J3A__]F#]O%9@]O[&8/U,9F#W/5&V8/;_1F
M#W/V!68/Z^YF#V^RI.'__V8/V^YF#]3%9@]OJO3A__]F#V_P9@]O@J3A__]F
M#]9T)!!F#V_S9@]STP)F#]M$)!!F#W/V'F8/Z][S#WZT).`"``!F#]3N9@]O
MLJ3A__]F#]O69@]O\68/[_-F#]359@]O[F8/;[*DX?__9@_O[V8/;_MF#]ON
M9@]O\&8/U.IF#W/6&V8/;]!F#W/R!68/Z]9F#V_T9@]S]AYF#W/4`F8/U-5F
M#V^JI.'__V8/Z^;S#WZT).@"``!F#]1T)"!F#]O59@]OJO3A__]F#^_\9@_4
M[F8/;[*DX?__9@_;SF8/U,UF#V]L)!!F#^_O9@]O^F8/<_<%9@_;[F8/U.EF
M#V_/9@]O^F8/<]<;9@_45"0P9@_KSV8/;_AF#W/W'F8/<]`"9@_4S68/;ZJD
MX?__9@_KQV8/U`0D9@_;S68/V]5F#]O%9@_6"68/UE$(9@_601!F#]1D)$!F
M#]1<)%!F#]OE9@_;W68/UF$89@_662"+A"3\`@``92L%%````'4+@<0,`P``
M6UY?7</H3P4``"Z-M"8`````C;8`````4^CHM___@<.&<```@^P4:GSHJK+_
M_V8/;X,$XO__QT`P``````\1`&8/;X,4XO__QT`T``````\10!!F#V^#).+_
M_\=`>``````/$4`@@\086\,NC;0F`````"Z-="8`55=6Z.'4__^!QB1P``!3
M@^P<BTPD.(M4)#"+1"0TB<MF#V[!P>$#B70D#,'['P-**#'M.THH9@]NRXGO
M&WHLB0PD9@]BP8EL)`3S#WY*,',,9@]OEC3B__]F#]3*\P]^'"1F#W/0'8M*
M>(UR.&8/U,%F#]9:*&8/UD(PA<ET<KU`````C7(X*<T[;"0X#T]L)#@!\3G!
M#X)$`0``C3PH.<AS"#GY#X*Y`0``B50D,(/L!%5048M<)!SHPK/__XM4)$")
MZ(/$$`-">(E">(/X0'0.@\0<6UY?7<.-M@````")T"EL)#CH!=3__XM4)#")
M^(-\)#@_#XZ/````C6A`B<.-0GB)5"0PB40D#(M$)#B)[XG%ZU(NC;0F````
M`&:0BT0D##G##X(]`0``B3PD\P]O`XM$)#"#[4"#PT"#QT`/$0;S#V]#T`\1
M1A#S#V]#X`\11B#S#V]#\`\11C#HC=/__X/]/WX8.=YRM(D\)#GS<[PY_G.X
MZ7BS__^-="8`BU0D,(L$)(EL)#@YQG(Y.?!S#HM,)#@!P3G.#X)3L___@WPD
M.`1S4(M,)#B%R0^%C````(M$)#B)0GB#Q!Q;7E]=PRZ-="8`BTPD.`'Q.<AS
MS^D=L___+HVT)@````"0C1PI.=@/@@FS__^-/"CIN/[__RZ-="8`BPB)2CB+
M?"0XBTPX_(E,/OR-3@2#X?PISBGP`W0D.(/F_(/^!'*5BWPD.(/F_#';BRP8
MB2P9@\,$.?-R\XE\)#CI=O___V:0#[8(B$HX]D0D.`(/A&/___^+?"0X#[=$
M./YFB40^_NE0____Z8NR___IAK+__V:0Z'#2__\%MVT``%575E.#[!R+7"0T
MBW0D,(E$)`2+0RCS#WY#*(UK.`_(B<>+0S!F#W/0`P_(B40D"&8/?L"#X#^-
M4`'&1`,X@(U$%0"#^C@/CDH!``"Y0````"G1=!LQTO;!`0^%U@$``,8$$`#&
M1!`!`(/"`CG*<O")V.C_T?__9@_OP`\10S@/$44@#Q%%$`\112B+1"0(B7MT
MB4-PB=CHVM'___,/?@.#[`QF#W/0&&8/?L"(!O,/?@-F#W/0$&8/?L"(1@&+
M`XAF`HL#B$8#\P]^0PAF#W/0&&8/?L"(1@3S#WY#"&8/<]`09@]^P(A&!8M#
M"(AF!HM#"(A&!_,/?D,09@]ST!AF#W[`B$8(\P]^0Q!F#W/0$&8/?L"(1@F+
M0Q"(9@J+0Q"(1@OS#WY#&&8/<]`89@]^P(A&#/,/?D,89@]ST!!F#W[`B$8-
MBT,8B&8.BT,8B$8/\P]^0R!F#W/0&&8/?L"(1A#S#WY#(&8/<]`09@]^P(A&
M$8M#((AF$HM#((A&$U.+7"04Z"RP__^#Q"Q;7E]=PXUT)@"Y.````"G1@_D$
M<G2-4`3'``````"#XOS'1`C\`````"G0`<B#X/R#^`0/@L7^__^)P;T$````
M@^'\B4PD#(U(_\'I`L<"`````(/A`3G%#X.@_O__A<EU7\<$*@````#'1"H$
M`````(M$)`R#Q0@YQ7+FZ7W^__\NC;0F`````(7)#X1M_O__Q@``]L$"#X1A
M_O__,=)FB50(_NE5_O__N@$```#&```YR@^"&O[__^DE_O__C78`QT($````
M`(M$)`R]"````#G%<HWI)/[__U6)Y5/HI++__X'#0FL``%#HNJ___UI;7<.#
M[`R#Q`S#````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E
M<FYA;',Z.E!!4CHZ0D]/5`!E>&4`+W!R;V,O)6DO)7,`+@!005)?5$5-4`!0
M05)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$52
M3$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%2
M7T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?
M5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?
M0TQ%04X`,0!L<V5E:R!F86EL960`<F5A9"!F86EL960`3$1?3$E"4D%265]0
M051(`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315(`55-%4DY!344`)3`R
M>`!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@!S:&]R="!R96%D`"5S)7-C86-H
M92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P`8`'!E<FP`
M,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`V-``M90`M+0```"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@
M*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`
M`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H`````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D
M,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S
M:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?
M;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?
M34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@
M("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-
M04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM
M>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@
M)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@
M+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@
M:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P
M*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK
M7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD
M97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D
M:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A
M<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP
M(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD
M:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII
M9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$
M25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)
M6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D
M=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE
M(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<
M(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@
M97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D
M=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N
M86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q
M6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z
M.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A
M;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH
M/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@
M("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD[
M"E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G
M;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@
M)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P
M<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER
M97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN
M9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S
M*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@
M4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#
M04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD[
M"FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@
M>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*
M?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?
M1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP
M86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)
M3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,
M15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L
M("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H
M92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)
M3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^
M('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E
M;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH
M/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA
M;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS
M=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@
M)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[
M)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN
M9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H
M)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP
M9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H
M+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS
M965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@
M/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*
M)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A
M=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE
M(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL
M960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^
M("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR
M97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S
M<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE
M=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("10
M2UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%
M('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*
M?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@
M(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U
M;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!
M4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET
M>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H
M"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L
M;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'
M5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD
M14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@
M;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H
M0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ
M*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*
M96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q
M("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I
M('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U
M:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B
M/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D
M(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]
M"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2![
M"F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%2
M1U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70[
M"GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I
M('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G
M/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D
M<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q
M6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T
M85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O
M;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS
M.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ
M("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D
M<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I
M;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID
M:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E
M<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I
M(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?
M0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U12
M54Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D
M;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY
M("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI
M('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX[
M"GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*
M?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_
M.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*
M?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER
M92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E
M<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R
M"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO
M?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T
M96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H
M)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME
M>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF
M("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M
M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D
M97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE
M>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*
M:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D
M,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N
M86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H
M<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E
M9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92![
M"FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT
M(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I
M.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N
M=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C
M:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L
M($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I
M+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@
M)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z
M:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T
M(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP
M<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE
M7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@
M)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R
M.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M
M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*
M)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N
M9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP
M0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L
M;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-
M04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A
M:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*
M?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G
M;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N
M($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@
M9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E
M=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E
M861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z
M.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T
M<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A
M8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE
M;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M
M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO
M/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=
M*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE
M(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A
M8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M
M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T
M7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E
M<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A
M8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@
M=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@
M?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A
M;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"
M=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R
M92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS
M8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A
M<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N
M.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%2
M7U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N
M9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W
M=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D
M("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U
M<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D
M("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU
M;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE
M7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE
M(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D
M9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F
M<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A
M9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B
M7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ
M92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@
M/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L
M;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T
M96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B
M)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M
M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N
M=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N
M86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@
M(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D
M=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@
M)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=
M.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E
M;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M
M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92![
M"FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?
M4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O
M9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P
M<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@
M<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L
M:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY
M("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II
M9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D
M<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET
M("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@
M97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%
M35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA
M;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@
M;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E
M>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92([
M"GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D
M14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R
M;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_
M($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@
M5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N
M86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[
M7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS
M=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]
M*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,
M25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT[
M"GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6
M>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@
M)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@
M>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U
M<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<
M;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R![
M"G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P
M("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E
M>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O
M<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI
M9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R
M9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D
M<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S
M<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@
M:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`
M.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@
M:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``0T%#2$4`
M`'!E<FQX<VDN8P````````#_____`````/____\``````/\`````````````
M`````/____\``````````````````/\`````````````````F7F"6@``````
M`````````*'KV6X```````````````#<O!N/````````````````UL%BR@``
M``````````````$C16<`````B:O-[P````#^W+J8`````'94,A``````\.'2
MPP````````````````$````````````````````!&P,[$`$``"$```#P7O__
M+`$``&!B__]0`0``@&+__U@$``""8O__B`4``(1B__\(#0``D&+__\@+``"`
M9O__9`$``%!G___(`0``X&?__Q0"``!@:?__Q`(``,!K__]$`P``(&S__Y0#
M``!@;/__P`,``(!M__]T!```D&W__X@$``#@;___I`4``"!P___4!0``$''_
M_TP&``!`=?__C`8``+!U__^H!@``\'7__]`&``"`=___@`<``+!W__^L!P``
M<'C__P`(``"`?___;`H``+"!__]<"P``=8+__Q`,``!Y@O__)`P``(""__\X
M#```,*W__WP,``"0K?__H`P```"P__\D#0``<;+__W0-```4``````````%Z
M4@`!?`@!&PP$!(@!```@````'````+Q=__]P`P````X(1@X,2@\+=`1X`#\:
M.RHR)"(0````0`````AA__\8`````````&````!4````%&7__\<`````00X(
MA0)##@R'`T$.$(8$00X4@P5.#C!_#C1!#CA$#CQ!#D!(#C!9"@X40\,.$$'&
M#@Q!QPX(0<4.!$@+=`H.%$/##A!!Q@X,0<<."$'%#@1!"P!(````N````(!E
M__^0`````$$."(8"00X,@P-1#K@!50Z\`4$.P`%(#K`!80ZX`4(.O`%!#L`!
M2`ZP`6L*#@Q!PPX(0<8.!$$+````K`````0!``#$9?__?@$```!!#@B%`D$.
M#(<#00X0A@1!#A2#!5$.T`%S"@X40<,.$$'&#@Q!QPX(0<4.!$0+0P[<`4$.
MX`%(#M`!20[<`4$.X`%(#M`!<P[<`4$.X`%P#N0!00[H`4$.[`%!#O`!2`[8
M`44.W`%!#N`!2`[0`5@.W`%!#N`!2`[0`4,.W`%!#N`!2`[0`4,.W`%!#N`!
M2`[0`4\.W`%!#N`!4`[0`0!\````M`$``)1F__]8`@```$$."(4"10X,AP-!
M#A"&!$$.%(,%3@Y,5@Y02`Y`6@Y,0PY03`Y``D\.3$L.4$@.0`*$"@X40<,.
M$$'&#@Q!QPX(0<4.!$D+`F0.3$$.4%(.0%0.1$4.2$4.3$$.4%0.0%D.2$$.
M3$$.4$X.0````$P````T`@``=&C__UH`````00X(A@)!#@R#`TX.$$T.%$P.
M&$$.'$,.($8.'$<.&$(.'$$.($$.)$<.*$<.+$,.,$@.#$'##@A!Q@X$````
M*````(0"``"$:/__-@````!!#@B#`DX.$$<.%$P.&$$.'$D.($@."$'##@24
M````L`(``)AH__\9`0```$$."(4"00X,AP-!#A"&!$$.%(,%1@Z4($H.E$!'
M#K!`8@Z\0$<.P$!!#L1`1P[(0$4.S$!%#M!`2`ZP0%L.M$!%#KA`2`Z\0$$.
MP$!(#K!`20Z\0$0.P$!(#K!`:`ZT0$$.N$!!#KQ`00[`0$P.L$!6"@X40\,.
M$$'&#@Q!QPX(0<4.!$D+`!@```!(`P``(%[__P(`````#K!`@P6%`H8$AP,0
M````9`,```1I__\%`````````/P```!X`P```&G__T@"````00X(A0)!#@R'
M`T$.$(8$00X4@P5&#I0@2@[@(7\.Z"%"#NPA0P[P(4@.X"%M"@X40<,.$$'&
M#@Q!QPX(0<4.!$<+0P[L(4$.\"%&#NPA00[H(4L.["%!#O`A2`[@(7H.Z"%!
M#NPA00[P(4@.X"%'#NPA00[P(4@.X"%G#NPA00[P(4@.X"%%#NPA1`[P(4@.
MX"%.#N@A1`[L(4(.\"%(#N`A`DL.Z"%$#NPA1`[P(4$.]"%$#O@A10[\(4@.
M@")(#N`A40[H(40.["%!#O`A2`[@(5\.Z"%"#NPA00[P(4@.X"%8#NPA00[P
M(4@.X"$8````>`0``/)<__\"``````[@(8,%A0*&!(<#+````)0$```T:O__
M,@````!!#@B&`D$.#(,#3@X81@X<00X@6`X,0<,."$'&#@0`=````,0$``!$
M:O__Z0````!!#@B&`D$.#(,#1@Z,($<.H"!T#JP@00ZP($@.H"!0#J@@00ZL
M($4.L"!0#J`@8`ZH($(.K"!!#K`@2`Z@($X.K"!!#K`@2`Z@(%8*#@Q!PPX(
M0<8.!$0+0PZL($<.L"!(#J`@````/````#P%``"\:O__)`0```!!#@B%`D$.
M#(<#00X0A@1,#A2#!4,.0`/@`PH.%$?##A!!Q@X,0<<."$'%#@1%"Q@```!\
M!0``K&[__V$`````30X@`D0*#@1'"P`D````F`4```!O__\T`````$$."(,"
M3@X01PX400X81`X<2`X@````K````,`%```8;___A`$```!!#@B%`D$.#(<#
M00X0A@1!#A2#!4<,`Y2`!$X-!$,.P(`$70[$@`1"#LB`!$(.S(`$00[0@`0"
M0@[`@`12#L2`!$0.R(`$1`[,@`1!#M"`!$@.P(`$3@[$@`1%#LB`!$$.S(`$
M00[0@`1(#L"`!`)H"@X40<,.$$'&#@Q!QPX(0<4.!$0+=`H.S(`$1P[0@`1%
M"T,*#LR`!$<.T(`$10LH````<`8``/AO__\K`````$$."(,"3@X02`X<00X@
M2`X020X(0<,.!````%````"<!@``_&___[P`````00X(A0)!#@R'`T$.$(8$
M00X4@P5.#D!]"@X40\,.$$'&#@Q!QPX(0<4.!$L+0PY,00Y0;0Y41PY800Y<
M00Y@3`Y``&@"``#P!@``:'#__Q`'````00X(A0)!#@R'`T$.$(8$00X4@P51
M#L`"`N$.S`)!#M`"2`[``E4.S`)!#M`"2`[``D,.S`)%#M`"2`[``F8.Q`)'
M#L@"00[,`D$.T`)/#L`"`D4.S`)!#M`"2`[``GH.S`)!#M`"1@[,`D0.T`)=
M#LP"1P[(`D0.S`)!#M`"2P[4`D<.V`)##MP"00[@`D@.R`)%#LP"00[0`D@.
MP`)8#L@"00[,`D0.T`)(#L`"7@[$`D8.R`)'#LP"2`[0`D@.P`)G"@X40\,.
M$$'&#@Q!QPX(0<4.!$@+0P[,`D0.T`)(#L`"`EP.S`)(#M`"2`[``E@.S`)$
M#M`"2`[``GD.S`)!#M`"5P[``DL.R`)!#LP"1@[0`DP.P`)+#LP"1`[0`D@.
MP`)*#L@"1P[,`DT.T`)(#L`"`G(.R`)!#LP"00[0`DH.U`)$#M@"00[<`D$.
MX`)(#L`"9@[$`D$.R`)!#LP"00[0`D0.U`)$#M@"1`[<`D$.X`)(#L`"0P[(
M`D4.S`)!#M`"2`[``D@.S`)$#M`"6P[``D@.S`)!#M`"1`[4`D8.V`)'#MP"
M2`[@`D@.P`),#LP"00[0`E@.P`)?#L@"0@[,`D0.T`)(#L`"9@[$`D0.R`)!
M#LP"10[0`DP.Q`)"#L@"2`[,`D4.T`),#L`"<`[$`D\.R`)!#LP"00[0`DP.
MQ`)"#L@"2`[,`D4.T`)(#L`"6@[(`D$.S`)'#M`"1`[4`D0.V`)!#MP"00[@
M`D@.P`)7#LP"00[0`DP.P`),#L@"1P[,`DD.T`)(#L`"7`[,`D<.T`(`[```
M`%P)```,=?__+P(```!!#@B%`D$.#(<#00X0A@1!#A2#!4X.0`))#D1"#DA!
M#DQ!#E!(#D!)#D1'#DA%#DQ##E!+#D!4#D1"#DA!#DQ##E!(#D!>#D1!#DA%
M#DQ##E!(#D!##D1(#DA!#DQ##E!(#D1'#DA!#DQ##E!<#D!-#DA%#DQ!#E!(
M#D!E"@X40<,.$$'&#@Q!QPX(0<4.!$,+0PH.3$8.4$@.0$T.3$<.4$L+9`Y$
M00Y(10Y,00Y05`Y`3`Y(00Y,0PY02`Y`1@H.1$P.2$(.3$<.4$X+20Y$0@Y(
M00Y,00Y02`Y`````:````$P*``!,=O__Q0````!!#@B'`D$.#(8#00X0@P1.
M#B`"30H.$$'##@Q!Q@X(0<<.!$<+0PXL00XP2`XL00XH0@XL00XP6`XD2`XH
M00XL00XP2`X@5`H.$$/##@Q!Q@X(0<<.!$4+````1````+@*``#`5O__/`(`
M``!$#`$`21`%`G4`01`'`G5\1!`&`G5X$`,"=71,#P-U<`8#9P$*P0P!`$'#
M0<9!QT'%0PP$!$$+$``````+``!==O__!``````````0````%`L``$UV__\$
M`````````$`````H"P``0';__Z(J````3`X(A0)!#@R'`T$.$(8$00X4@P5&
M#J`&`X,J"@X40<,.$$'&#@Q!QPX(0<4.!$$+````(````&P+``"LH/__4P``
M``!!#@B#`DX.'$(.(`)`#@A!PPX$9````)`+``#HH/__;@(```!!#@B%`D$.
M#(<#00X0A@1,#A2#!4,.,`*@#C1!#CA!#CQ!#D!2#C!."@X40<,.$$'&#@Q!
MQPX(0<4.!$<+`MX*#A1!PPX00<8.#$''#@A!Q0X$1@L````8````^`L``'15
M__\"``````XP@P6%`H8$AP,`3````!0,``#4HO__<0(```!+#@B%`D$.#(<#
M00X0A@1!#A2#!4,.,`*<#CP"W@Y`3`X40<,.$$'&#@Q!QPX(0<4.!$4.,(,%
MA0*&!(<#```@````9`P``/6D__\9`````$$."(4"0@T%08,#4\-!Q0P$!```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````%`7``#@%@```0````(#```!````#0,``!T````]!```
M#``````0```-````JF,``!D```#DS0``&P````0````:````Z,T``!P````$
M````]?[_;Q@"```%````!`D```8```#T`@``"@```%L$```+````$````!4`
M`````````P```-S.```"````L`$``!0````1````%P`````.```1````8`T`
M`!(```"@````$P````@````>````"````/O__V\!```(^O__;P<`````````
M````````````````````````````````````````````````[,T`````````
M````)A```#80``!&$```5A```&80``!V$```AA```)80``"F$```MA```,80
M``#6$```YA```/80```&$0``%A$``"81```V$0``1A$``%81``!F$0``=A$`
M`(81``"6$0``IA$``+81``#&$0``UA$``.81``#V$0``!A(``!82```F$@``
M-A(``$82``!6$@``9A(``'82``"&$@``EA(``*82``"V$@``QA(``-82``#F
M$@``]A(```83```6$P``)A,``#83``!&$P``5A,``&83``!V$P``L!,`````
M````````JF,`````````$```````````````````````````````````````
M``````````````````#0```*4$%2+G!M"@````#8<@``1T-#.B`H06QP:6YE
M(#$T+C,N,"D@,30N,RXP```N<VAS=')T86(`+FYO=&4N9VYU+F)U:6QD+6ED
M`"YN;W1E+F=N=2YP<F]P97)T>0`N:6YT97)P`"YG;G4N:&%S:``N9'EN<WEM
M`"YD>6YS='(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G!L="YG;W0`+G1E
M>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI
M=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9&%T80`N8G-S`"YC;VUM
M96YT````````````````````````````````````````````````````````
M```+````!P````(```"T`0``M`$``"0```````````````0`````````'@``
M``<````"````V`$``-@!```H```````````````$`````````#$````!````
M`@`````"`````@``%P```````````````0`````````Y````]O__;P(````8
M`@``&`(``-P````%``````````0````$````0P````L````"````]`(``/0"
M```0!@``!@````$````$````$````$L````#`````@````0)```$"0``6P0`
M`````````````0````````!3````"0````(```!@#0``8`T``*`````%````
M``````0````(````7`````D```!"``````X````.``"P`0``!0```!0````$
M````"````&4````!````!@`````0````$```!P```````````````0``````
M``!@`````0````8````0$```$!```'`#`````````````!`````$````:P``
M``$````&````@!,``(`3```8```````````````(````"````'0````!````
M!@```*`3``"@$P``"E``````````````(`````````!Z`````0````8```"J
M8P``JF,```<```````````````$`````````@`````$````"`````'````!P
M```@00`````````````0`````````(@````!`````@```""Q```@L0``%`$`
M````````````!`````````"6`````0````(````TL@``-+(``(@,````````
M``````0`````````H`````X````#````Y,T``.3-```$```````````````$
M````!````*P````/`````P```.C-``#HS0``!```````````````!`````0`
M``"X````!@````,```#LS0``[,T``/`````&``````````0````(````;P``
M``$````#````W,X``-S.```D`0`````````````$````!````,$````!````
M`P````#0````T```%```````````````!`````````#'````"`````,````4
MT```%-```"P```````````````0`````````S`````$````P`````````!30
M```<```````````````!`````0````$````#```````````````PT```U0``
1`````````````0``````````
